@@ -29,9 +29,10 @@
 #include <gio/gio.h>
 
 #include "gtlsbackend-openssl.h"
+#include "visibility.h"
 
 
-G_MODULE_EXPORT void
+GLIB_NETWORKING_EXPORT void
 g_io_openssl_load (GIOModule *module)
 {
   gchar *locale_dir;
@@ -54,12 +55,12 @@ g_io_openssl_load (GIOModule *module)
   g_free (locale_dir);
 }
 
-G_MODULE_EXPORT void
+GLIB_NETWORKING_EXPORT void
 g_io_openssl_unload (GIOModule *module)
 {
 }
 
-G_MODULE_EXPORT gchar **
+GLIB_NETWORKING_EXPORT gchar **
 g_io_openssl_query (void)
 {
   return g_strsplit (G_TLS_BACKEND_EXTENSION_POINT_NAME, "!", -1);
